@@ -6,6 +6,7 @@
 
 #include <contrib/ucw/lib.h>
 #include <contrib/ucw/mempool.h>
+#include <errno.h>
 #include <libknot/errcode.h>
 #include <string.h>
 #include <sys/resource.h>
@@ -275,7 +276,7 @@ static void set_so(int fd, int so_option, int value, const char *descr)
 	}
 }
 
-int io_listen_udp(uv_loop_t *loop, uv_udp_t *handle, int fd)
+int io_listen_udp(uv_loop_t *loop, uv_udp_t *handle, int fd, bool doq)
 {
 	if (!handle) {
 		return kr_error(EINVAL);
@@ -292,7 +293,9 @@ int io_listen_udp(uv_loop_t *loop, uv_udp_t *handle, int fd)
 	uv_handle_t *h = (uv_handle_t *)handle;
 	check_bufsize(h);
 	/* Handle is already created, just create context. */
-	struct session2 *s = session2_new_io(h, KR_PROTO_UDP53, NULL, 0, false);
+	struct session2 *s = session2_new_io(h,
+			doq ? KR_PROTO_DOQ : KR_PROTO_UDP53,
+			NULL, 0, false);
 	kr_require(s);
 
 	int socklen = sizeof(union kr_sockaddr);
@@ -381,27 +384,26 @@ static void tcp_accept_internal(uv_stream_t *master, int status, enum kr_proto g
 		return;
 	}
 
-	struct session2 *s;
-	int res = io_create(master->loop, &s, SOCK_STREAM, AF_UNSPEC, grp,
-			NULL, 0, false);
-	if (res) {
-		if (res == UV_EMFILE) {
-			the_worker->too_many_open = true;
-			the_worker->rconcurrent_highwatermark = the_worker->stats.rconcurrent;
-		}
-		/* Since res isn't OK struct session wasn't allocated \ borrowed.
-		 * We must release client handle only.
-		 */
+	uv_handle_t *client;
+	if (io_create(master->loop, &client, SOCK_STREAM, AF_UNSPEC)) {
 		return;
 	}
 
-	kr_require(s->outgoing == false);
-
-	uv_tcp_t *client = (uv_tcp_t *)session2_get_handle(s);
-	if (uv_accept(master, (uv_stream_t *)client) != 0) {
-		/* close session, close underlying uv handles and
-		 * deallocate (or return to memory pool) memory. */
-		session2_close(s);
+	struct session2 *s = session2_new_io(client, grp, NULL, 0, false);
+	int res = uv_accept(master, (uv_stream_t *)client);
+	if (s == NULL || res) {
+		if (s == NULL) {
+			/* Since res isn't OK struct session wasn't
+			 * allocated \ borrowed. We must release client handle
+			 * only. But first accept the connection, as it has
+			 * already been established by the kernel and
+			 * it is required for proper termination. */
+			uv_close(client, (uv_close_cb)free);
+		} else {
+			/* close session, close underlying uv handles and
+			 * deallocate (or return to memory pool) memory. */
+			session2_close(s);
+		}
 		return;
 	}
 
@@ -409,14 +411,14 @@ static void tcp_accept_internal(uv_stream_t *master, int status, enum kr_proto g
 	 * even if we listened on a wildcard address. */
 	struct sockaddr *sa = session2_get_peer(s);
 	int sa_len = sizeof(struct sockaddr_in6);
-	int ret = uv_tcp_getpeername(client, sa, &sa_len);
+	int ret = uv_tcp_getpeername((uv_tcp_t *)client, sa, &sa_len);
 	if (ret || sa->sa_family == AF_UNSPEC) {
 		session2_close(s);
 		return;
 	}
 	sa = session2_get_sockname(s);
 	sa_len = sizeof(struct sockaddr_in6);
-	ret = uv_tcp_getsockname(client, sa, &sa_len);
+	ret = uv_tcp_getsockname((uv_tcp_t *)client, sa, &sa_len);
 	if (ret || sa->sa_family == AF_UNSPEC) {
 		session2_close(s);
 		return;
@@ -431,7 +433,7 @@ static void tcp_accept_internal(uv_stream_t *master, int status, enum kr_proto g
 	session2_event(s, PROTOLAYER_EVENT_CONNECT, NULL);
 	session2_timer_start(s, PROTOLAYER_EVENT_GENERAL_TIMEOUT,
 			timeout, idle_in_timeout);
-	io_start_read((uv_handle_t *)client);
+	io_start_read(client);
 }
 
 static void tcp_accept(uv_stream_t *master, int status)
@@ -916,40 +918,36 @@ int io_listen_xdp(uv_loop_t *loop, struct endpoint *ep, const char *ifname)
 }
 #endif
 
-int io_create(uv_loop_t *loop, struct session2 **out_session, int type,
-              unsigned family, enum kr_proto grp,
-              struct protolayer_data_param *layer_param,
-              size_t layer_param_count, bool outgoing)
+int io_create(uv_loop_t *loop, uv_handle_t **handle,
+              int type, unsigned family)
 {
-	*out_session = NULL;
+	*handle = NULL;
 	int ret = -1;
-	uv_handle_t *handle;
 	if (type == SOCK_DGRAM) {
 		uv_udp_t *udp = malloc(sizeof(uv_udp_t));
 		kr_require(udp);
 		ret = uv_udp_init(loop, udp);
 
-		handle = (uv_handle_t *)udp;
+		*handle = (uv_handle_t *)udp;
 	} else if (type == SOCK_STREAM) {
 		uv_tcp_t *tcp = malloc(sizeof(uv_tcp_t));
 		kr_require(tcp);
 		ret = uv_tcp_init_ex(loop, tcp, family);
-		uv_tcp_nodelay(tcp, 1);
-
-		handle = (uv_handle_t *)tcp;
+		if (ret != 0) {
+			uv_tcp_nodelay(tcp, 1);
+		}
+		*handle = (uv_handle_t *)tcp;
 	} else {
 		kr_require(false && "io_create: invalid socket type");
 	}
-	if (ret != 0) {
-		return ret;
+	if (ret != 0 && *handle) {
+		free(*handle);
 	}
-	struct session2 *s = session2_new_io(handle, grp, layer_param,
-			layer_param_count, outgoing);
-	if (s == NULL) {
-		ret = -1;
+	if (ret == UV_EMFILE) {
+		the_worker->too_many_open = true;
+		the_worker->rconcurrent_highwatermark = the_worker->stats.rconcurrent;
 	}
 
-	*out_session = s;
 	return ret;
 }
 
